---
title: 세금계산서 역발행 기능은 어떻게 이용할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: ''
tags:
  - 세금계산서 역발행
  - 기본 가이드
pgCompanies:
  - 공통
searchTags:
  - 역발행
  - 세금계산서
  - 회원가입
  - 팝빌
  - 세금계산서역발행
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="플랫폼사가 공급받는자로서 파트너정산 서비스에서 역발행 세금계산서를 작성 후 요청할 수 있습니다. 
공급자는 제휴사 사이트에 별도로 회원가입을 하지 않아도 자동으로 가입 처리가 진행됩니다. " title="" />

### 세금계산서 역발행이란?

- 세금계산서 발행 주체인 \[공급자]가 아니라, \[공급받는자]가 공급자 대신 세금계산서를 작성하여 \[공급자]에 발행 요청하는 기능입니다.
- 플랫폼사가 파트너에게 지급할 정산대금 정보를 정확히 세금계산서 작성 시 기입하고, 해당 내용을 바탕으로 공급자는 이메일을 수취하여 승인할 수 있는 구조이기 때문에 공급받는자와 공급자의 소통 비용을 줄이고 빠르고 효율적으로 세금계산서를 발행할 수 있도록 도울 수 있습니다.

### 역발행 기본 절차가 궁금해요!

<Callout content="공급받는자 (플랫폼사) " />

#### STEP 1. 공급받는자 국세청 연동 (최초 1회)

- \[세금계산서] 페이지 우측 최상단 \[세금계산서 연동 관리] 버튼을 눌러주세요.
- 사업자 정보, 담당자 정보를 기입하고 공동인증서를 등록해 주세요.
- 공동인증서는 최초 1회 등록 시 필요하며, 1년간 정보가 저장됩니다.

#### STEP 2. 공급자 국세청 연동 (최초 1회)

- 공급자의 기본 정보를 \[파트너 관리] 페이지에서 등록해주세요.
- \[파트너 관리] 페이지에서 \[국세청 연동] 버튼을 눌러서 제휴사를 통해 국세청과 통신할 수 있도록 연결해주세요. (최초 1회 진행)
  - 사업자 정보가 유효한 경우 즉시 연동이 완료되고 서비스 이용을 위한 제휴사에 가입됩니다. 가입 완료 시, 공급자에게 제휴사 팝빌의 회원가입 완료 이메일이 자동 발송됩니다.
  - 사업자 정보가 변경되면, 국세청 연동을 해제하고 정보를 수정한 뒤 다시 국세청에 연동해야 합니다.
  - 공급자도 공동인증서를 등록해야 국세청과 통신할 수 있습니다. 다만 공급받는자가 세금계산서 발행 요청 이메일을 보내면, 세금계산서 조회 페이지를 통해 손쉽게 등록할 수 있습니다.

#### STEP 3. 세금계산서 작성

- \[세금계산서 작성] 혹은 \[세금계산서 일괄등록] 기능을 클릭하고 역발행 세금계산서 문서를 작성해주세요.
  - 세금계산서 문서는 1개씩 작성할 수 있고, 대량으로 일괄 작성할 수 있습니다.
  - 임시 저장 기능을 이용할 수 있습니다.
- 이 때 공급자는 국세청에 연동된 파트너여야만 합니다.

#### STEP 4. 발행 요청

- \[발행 요청] 버튼을 눌러 공급자에게 세금계산서 승인 요청 이메일을 보냅니다.
- 이메일은 즉시 발송됩니다.

<Callout content="공급자 (파트너/하위셀러/입점사)" />

#### STEP 1. 공급받는자가 보낸 이메일 확인

- 공급자가 기재한 \[담당자 정보] 이메일 주소로 세금계산서가 도착합니다.

#### STEP 2. 세금계산서 조회

- 이메일 본문을 확인하고, \[전자세금계산서 조회] 버튼을 클릭합니다.
- 전자세금계산서 내용을 확인하기 위해 \[사업자등록번호]를 입력합니다. 입력 즉시 세금계산서 내용을 확인할 수 있습니다.

#### STEP 3. 공동인증서 등록 (최초 1회)

- 세금계산서를 발행 승인하거나 발행 거부하려면 최초 1회 공동인증서 등록이 필요합니다.
  - 법인용 공동인증서, 전자세금계산서용 공동인증서를 등록해야 합니다.
  - 공동인증서 등록은 최초 1회만 필요하며, 등록된 공동인증서는 1년간 정보가 저장됩니다.
  - 공동인증서 정보가 바뀌거나 만료되면, 공동인증서를 재등록 해야합니다.
- 공동인증서 등록 완료 후, 세금계산서 조회 페이지로 돌아가서 새로고침을 해주세요.

#### STEP 4. 세금계산서 발행 승인

- 이제 공급자는 세금계산서를 발행 승인하거나 발행 거부할 수 있습니다.
- 공급자가 발행 승인 시, 익일 3시에 국세청에 세금계산서가 일괄 전송됩니다.
- 발행을 승인한 뒤, 국세청에 세금계산서가 전송되기 전까지는 발행 취소가 가능합니다. (공급자에 의한 발행 취소)

### 어떤 제휴사와 연동되어 있나요?

- 파트너 정산 자동화 서비스의 \[세금계산서 역발행] 기능을 제공하는 제휴사는 (주)링크허브이며, 서비스명은 \[팝빌]입니다.
- 세금계산서 기능을 이용하려면 공급자와 공급받는자 모두 올바른 사업자/담당자 정보를 완료해야하며, 포트원 파트너정산 서비스를 통해서 \[팝빌] 서비스에 가입 연동되어야 합니다.

### 서비스 이용을 위해서 제휴사에 사이트에 가입해야 할까요?

- 아니오, 포트원은 팝빌 서비스 연동을 API를 통해서 진행하고 있습니다.
- 따라서 공급자와 공급받는자가 팝빌 서비스에 스스로 회원가입을 할 필요가 없고, 포트원 서비스 내의 \[국세청 연동] 을 완료하면 자동으로 회원가입이 완료됩니다.
- 팝빌 서비스에 회원가입이 완료되는 즉시, 입력한 담당자 이메일로 팝빌 회원가입 완료 이메일이 발송됩니다.

### 개인정보 처리에는 문제가 없나요? 우리 회사가 미리 준비해서 고지할 내용은 없나요?

- 파트너 정산 자동화 서비스의 \[송금대행 일괄지급], \[세금계산서 역발행] 등의 기능을 제공하기 위해 주식회사 코리아 포트원은 등록된 파트너의 개인정보를 제휴사에 (재)위탁하고 있습니다.
- (주)코리아포트원의 개인정보 처리방침은 [이 링크](https://portone.notion.site/f756e6b1a20d42e1af4dc887c9f8f420)를 참고해 주세요.
- 고객사는 서비스를 이용하기 위해 정산 대상자 \[파트너] 에게 개인정보 처리방침을 안내할 의무가 있습니다. 개인정보 위탁 및 재위탁에 대한 내용을 작성하여 파트너에게 안내해 주세요.
- 개인정보 처리방침 작성 가이드는 [이 링크](https://help.portone.io/content/platform_infosec "파트너정산 고객사 개인정보처리방침 작성 가이드 ")를 참고해 주세요.

### 서비스 이용에 관심이 있으시다면?

도입 문의를 남겨주시면 영업일 2일 이내 담당자가 연락 드립니다.

<Callout content="서비스 이용 문의 →" title="" />

###
